# -*- encoding : utf-8 -*-
class PagesController < ApplicationController
  filter_access_to [:index, :new, :create]
  filter_access_to [:show, :edit, :update, :destroy], attribute_check: true,
    load_method: :load_page
  filter_access_to [:admin, :history], require: :edit

  has_control_panel_applet :admin_applet,
    if: -> { show_admin? }

  def index
    @menu = Page.menu
    @page = Page.index
    @show_admin = show_admin?
  end

  def show
    @menu = Page.menu
    @page = Page.find_by_param(params[:id]) || not_found
    @show_admin = show_admin?
  end

  def history
    @page = Page.find_by_param(params[:id]) || not_found
    @revisions = @page.revisions
    @show_admin = show_admin?
  end

  def new
    @page = Page.new
  end

  def create
    @page = Page.new(params[:page])
    if @page.save
      flash[:success] = t("pages.create_success")
      redirect_to @page
    else
      flash.now[:error] = t("common.fields_missing_error")
      render :new
    end
  end

  def edit
    @page = Page.find_by_param(params[:id]) || not_found
  end

  def preview
    @content = params[:content]
    @content_type = params[:content_type]

    if request.xhr?
      render layout: false
    end
  end

  def update
    @page = Page.find_by_param(params[:id]) || not_found

    unless permitted_to? :edit_non_content_fields, @page
      params[:page].slice!(:title_no, :title_en, :content_no, :content_en)
    end

    if @page.update_attributes(params[:page])
      flash[:success] = t('pages.edit_success')
      redirect_to page_url @page
    else
      flash.now[:error] = t('common.fields_missing_error')
      render action: 'edit'
    end
  end

  def admin
    @pages = Page.with_permissions_to(:edit)
  end

  def destroy
    @page = Page.find(params[:id])
    @page.destroy
    flash[:success] = t("pages.destroy_success")
    redirect_to pages_path
  end

  def admin_applet
  end

  def change_language
    new_route = I18n.locale == :no ? { locale: 'en' } : { locale: 'no' }

    if @page
      new_route[:id] = I18n.locale == :no ? @page.name_en : @page.name_no
    end

    new_route
  end

  private

  def load_page
    Page.find_by_param(params[:id])
  end

  def not_found
    raise ActiveRecord::RecordNotFound.new
  end

  def show_admin?
    can_create = permitted_to?(:new, :pages)
    can_edit   = permitted_to?(:edit, :pages) && Page.with_permissions_to(:edit).present?
    can_create || can_edit
  end
end
